function u = pressure_exact_dr(R,k,x)
%
% function u = pressure_exact_dr(R,k,x)
%
% This function computes the radial derivative (i.e. d/dr) of the exact pressure field 
% for the problem where a point source is at the centre of a circle and the pressure 
% satisfies the boundary condition that it is zero (equation (2.31) in the notes).
%
% On entry:
%
% R     is the radius of the circle
% k     is the wavenumber
% x     is a 2x1 vector, the position vector of the point at which the
%       radial derivative is required
%
% On exit:
%
% u     is the radial derivative of the pressure at x
%
c = (i/4)*besselh(0,k*R)/besselj(0,k*R);
r = norm(x);
u = (i*k/4)*besselh(1,k*r) - c*k*besselj(1,k*r);